@@ -18,8 +18,9 @@ import subprocess
 import gzip
 import shutil
 import statistics
-from .misc import round_to_nearest_odd, get_compression_type, int_to_str, quit_with_error,\
-    strip_read_extensions, bold, dim, print_table, get_left_arrow, float_to_str
+
+from .misc import round_to_nearest_odd, get_compression_type, int_to_str, quit_with_error, \
+    bold, dim, print_table, get_left_arrow, float_to_str
 from .assembly_graph import AssemblyGraph
 from . import log
 
@@ -30,51 +31,21 @@ class BadFastq(Exception):
 
 def get_best_spades_graph(short1, short2, short_unpaired, out_dir, read_depth_filter, verbosity,
                           spades_path, threads, keep, kmer_count, min_k_frac, max_k_frac, kmers,
-                          no_spades_correct, expected_linear_seqs, spades_tmp_dir):
+                          expected_linear_seqs, largest_component, spades_graph_prefix,
+                          spades_options):
     """
-    This function tries a SPAdes assembly at different k-mers and returns the best.
-    'The best' is defined as the smallest dead-end count after low-depth filtering.  If multiple
-    graphs have the same dead-end count (e.g. zero!) then the highest kmer is used.
+    This function tries a SPAdes assembly at different k-mers and returns the best one.
     """
     spades_dir = os.path.join(out_dir, 'spades_assembly')
     if not os.path.exists(spades_dir):
         os.makedirs(spades_dir)
 
-    # SPAdes can possibly crash if given too many threads, so limit it to 32.
-    threads = min(threads, 32)
+    threads = min(threads, 32)  # SPAdes can possibly crash if given too many threads.
+    check_fastqs(short1, short2, short_unpaired)
+    reads = (short1, short2, short_unpaired)
 
-    # Make sure that the FASTQ files look good.
-    using_paired_reads = bool(short1) and bool(short2)
-    using_unpaired_reads = bool(short_unpaired)
-    if using_paired_reads:
-        count_1, count_2 = 0, 0
-        try:
-            count_1 = get_read_count(short1)
-        except BadFastq:
-            quit_with_error('this read file is not a properly formatted FASTQ: ' + short1)
-        try:
-            count_2 = get_read_count(short2)
-        except BadFastq:
-            quit_with_error('this read file is not a properly formatted FASTQ: ' + short2)
-        if count_1 != count_2:
-            quit_with_error('the paired read input files have an unequal number of reads')
-    if using_unpaired_reads:
-        try:
-            get_read_count(short_unpaired)
-        except BadFastq:
-            quit_with_error('this read file is not properly formatted as FASTQ: ' + short_unpaired)
-
-    if no_spades_correct:
-        reads = (short1, short2, short_unpaired)
-    else:
-        reads = spades_read_correction(short1, short2, short_unpaired, spades_dir, threads,
-                                       spades_path, keep, spades_tmp_dir)
-    if kmers is not None:
-        kmer_range = kmers
-    else:
-        kmer_range = get_kmer_range(short1, short2, short_unpaired, spades_dir, kmer_count,
-                                    min_k_frac, max_k_frac, spades_path)
-    assem_dir = os.path.join(spades_dir, 'assembly')
+    kmer_range = get_kmer_range(kmers, short1, short2, short_unpaired, spades_dir, kmer_count,
+                                min_k_frac, max_k_frac, spades_path)
 
     log.log_section_header('SPAdes assemblies')
     log.log_explanation('Unicycler now uses SPAdes to assemble the short reads. It scores the '
@@ -83,26 +54,24 @@ def get_best_spades_graph(short1, short2, short_unpaired, out_dir, read_depth_fi
                         'function is 1/(c*(d+2)), where c is the contig count and d is the '
                         'dead end count.')
 
-    # Conduct a SPAdes assembly for each k-mer and score them to choose the best.
     if verbosity > 1:
         spades_results_table = [['K-mer', 'Contigs', 'Links', 'Total length', 'N50',
                                  'Longest contig', 'Dead ends', 'Score']]
     else:
         spades_results_table = [['K-mer', 'Contigs', 'Dead ends', 'Score']]
-    best_score = 0.0
-    best_kmer = 0
-    best_graph_filename = ''
 
     graph_files, insert_size_mean, insert_size_deviation = \
-        spades_assembly(reads, assem_dir, kmer_range, threads, spades_path, spades_tmp_dir)
+        run_spades_all_kmers(reads, spades_dir, kmer_range, threads, spades_path,
+                             spades_graph_prefix, spades_options)
 
     existing_graph_files = [x for x in graph_files if x is not None]
     if not existing_graph_files:
         quit_with_error('SPAdes failed to produce assemblies. '
-                        'See spades_assembly/assembly/spades.log for more info.')
-    median_segment_count = statistics.median(count_segments_in_spades_fastg(x)
+                        'See spades_assembly/spades.log for more info.')
+    median_segment_count = statistics.median(count_segments_in_gfa(x)
                                              for x in existing_graph_files)
 
+    best_score, best_kmer, best_graph_filename = 0.0, 0, ''
     for graph_file, kmer in zip(graph_files, kmer_range):
         table_line = [int_to_str(kmer)]
 
@@ -112,8 +81,7 @@ def get_best_spades_graph(short1, short2, short_unpaired, out_dir, read_depth_fi
             spades_results_table.append(table_line)
             continue
 
-        assembly_graph = AssemblyGraph(graph_file, kmer, paths_file=None,
-                                       insert_size_mean=insert_size_mean,
+        assembly_graph = AssemblyGraph(graph_file, kmer, insert_size_mean=insert_size_mean,
                                        insert_size_deviation=insert_size_deviation)
 
         # If this graph has way too many segments, then we will just skip it because very complex
@@ -126,7 +94,7 @@ def get_best_spades_graph(short1, short2, short_unpaired, out_dir, read_depth_fi
             continue
 
         log.log('\nCleaning k{} graph'.format(kmer), 2)
-        assembly_graph.clean(read_depth_filter)
+        assembly_graph.clean(read_depth_filter, largest_component)
         clean_graph_filename = os.path.join(spades_dir, ('k%03d' % kmer) + '_assembly_graph.gfa')
         assembly_graph.save_to_gfa(clean_graph_filename, verbosity=2)
 
@@ -144,8 +112,7 @@ def get_best_spades_graph(short1, short2, short_unpaired, out_dir, read_depth_fi
         # Prepare the table line for this k-mer graph.
         table_line += [int_to_str(segment_count)]
         if verbosity > 1:
-            n50, shortest, lower_quartile, median, upper_quartile, longest = \
-                assembly_graph.get_contig_stats()
+            n50, shortest, _, median, _, longest = assembly_graph.get_contig_stats()
             table_line += [int_to_str(assembly_graph.get_total_link_count()),
                            int_to_str(assembly_graph.get_total_length()),
                            int_to_str(n50), int_to_str(longest)]
@@ -153,37 +120,17 @@ def get_best_spades_graph(short1, short2, short_unpaired, out_dir, read_depth_fi
         spades_results_table.append(table_line)
 
         if score > best_score:
-            best_kmer = kmer
-            best_score = score
-            best_graph_filename = graph_file
+            best_kmer, best_score, best_graph_filename = kmer, score, graph_file
 
     log.log('', 2)
 
     if not best_kmer:
         quit_with_error('none of the SPAdes graphs were suitable for scaffolding in Unicycler')
 
-    # If the best k-mer is the top k-mer, then SPAdes has already done the repeat resolution and
-    # we can just grab it now. Easy! If the best k-mer was a different k-mer size, then we need
-    # to run SPAdes again to get that repeat resolution.
-    if best_kmer != kmer_range[-1]:
-        new_kmer_range = [x for x in kmer_range if x <= best_kmer]
-        graph_file, insert_size_mean, insert_size_deviation = \
-            spades_assembly(reads, assem_dir, new_kmer_range, threads, spades_path, spades_tmp_dir,
-                            just_last=True)
-        best_graph_filename = graph_file
-    paths_file = os.path.join(assem_dir, 'contigs.paths')
-    if os.path.isfile(paths_file):
-        copied_paths_file = os.path.join(spades_dir,
-                                         'k' + ('%03d' % best_kmer) + '_contigs.paths')
-        shutil.copyfile(paths_file, copied_paths_file)
-    else:
-        paths_file = None
-
-    # Now we can load and clean the graph again, this time giving it the SPAdes contig paths.
-    assembly_graph = AssemblyGraph(best_graph_filename, best_kmer, paths_file=paths_file,
+    assembly_graph = AssemblyGraph(best_graph_filename, best_kmer,
                                    insert_size_mean=insert_size_mean,
                                    insert_size_deviation=insert_size_deviation)
-    assembly_graph.clean(read_depth_filter)
+    removed_count, removed_length = assembly_graph.clean(read_depth_filter, largest_component)
     clean_graph_filename = os.path.join(spades_dir, 'k' + str(best_kmer) + '_assembly_graph.gfa')
     assembly_graph.save_to_gfa(clean_graph_filename, verbosity=2)
 
@@ -197,173 +144,101 @@ def get_best_spades_graph(short1, short2, short_unpaired, out_dir, read_depth_fi
                 row_colour={best_kmer_row: 'green'},
                 row_extra_text={best_kmer_row: ' ' + get_left_arrow() + 'best'})
 
+    # Report on the results of the read depth filter (can help with identifying levels of
+    # contamination).
+    log.log('\nRead depth filter: removed {} contigs totalling {} bp'.format(removed_count,
+                                                                             removed_length))
     # Clean up.
+    if keep < 1:
+        for g in graph_files:
+            if os.path.isfile(g):
+                log.log('Deleting ' + g)
+                os.remove(g)
     if keep < 3 and os.path.isdir(spades_dir):
-        log.log('\nDeleting ' + spades_dir + '/')
+        log.log('Deleting ' + spades_dir + '/')
         shutil.rmtree(spades_dir, ignore_errors=True)
-    if keep < 3 and spades_tmp_dir is not None and os.path.isdir(spades_tmp_dir):
-        log.log('Deleting ' + spades_tmp_dir + '/')
-        shutil.rmtree(spades_tmp_dir, ignore_errors=True)
 
     return assembly_graph
 
 
-def spades_read_correction(short1, short2, unpaired, spades_dir, threads, spades_path, keep,
-                           spades_tmp_dir):
+def run_spades_all_kmers(read_files, spades_dir, kmers, threads, spades_path, spades_graph_prefix,
+                         spades_options):
     """
-    This runs SPAdes with the --only-error-correction option.
+    SPAdes is run with all k-mers up to the top one. For example:
+      * round 1: 25
+      * round 2: 25,43
+      * round 3: 25,43,59
+      * round 4: 25,43,59,73
+
+    This is because it only saves the necessary graph information for the final k-mer. The first
+    round is a normal SPAdes run, and subsequent rounds use the --restart-from option.
     """
-    log.log_section_header('SPAdes read error correction')
-    log.log_explanation('Unicycler uses the SPAdes read error correction module to reduce the '
-                        'number of errors in the short read before SPAdes assembly. This can make '
-                        'the assembly faster and simplify the assembly graph structure.')
-
-    using_paired_reads = bool(short1) and bool(short2)
-    using_unpaired_reads = bool(unpaired)
-
-    # If the corrected reads already exist, then we just use them and proceed.
-    corrected_1 = os.path.join(spades_dir, 'corrected_1.fastq.gz')
-    corrected_2 = os.path.join(spades_dir, 'corrected_2.fastq.gz')
-    corrected_u = os.path.join(spades_dir, 'corrected_u.fastq.gz')
-    corrected_1_exists = os.path.isfile(corrected_1)
-    corrected_2_exists = os.path.isfile(corrected_2)
-    corrected_u_exists = os.path.isfile(corrected_u)
-
-    reads_already_exist = True
-    if using_paired_reads and (not corrected_1_exists or not corrected_2_exists):
-        reads_already_exist = False
-    if using_unpaired_reads and not corrected_u_exists:
-        reads_already_exist = False
-
-    if reads_already_exist:
-        log.log('Corrected reads already exist. Will use these reads instead of running SPAdes '
-                'error correction:')
-        if using_paired_reads:
-            log.log('  ' + corrected_1)
-            log.log('  ' + corrected_2)
-        if using_unpaired_reads:
-            log.log('  ' + corrected_u)
-        if not using_paired_reads:
-            corrected_1, corrected_2 = None, None
-        if not using_unpaired_reads:
-            corrected_u = None
-        return corrected_1, corrected_2, corrected_u
-
-    # If the corrected reads don't exist, then we run SPAdes in error correction only mode.
-    read_correction_dir = os.path.join(spades_dir, 'read_correction')
-    command = [spades_path]
-    if using_paired_reads:
-        assert bool(short1) and bool(short2)
-        command += ['-1', short1, '-2', short2]
-    if using_unpaired_reads:
-        command += ['-s', unpaired]
-    command += ['-o', read_correction_dir, '--threads', str(threads), '--only-error-correction']
-    if spades_tmp_dir is not None:
-        command += ['--tmp-dir', spades_tmp_dir]
-    process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-
-    while process.poll() is None:
-        spades_output = process.stdout.readline().rstrip().decode()
-        if 'Command line:' in spades_output:
-            spades_output = ' '.join(spades_output.split()).replace('Command line: ', '')
-            log.log('Command: ' + bold(spades_output))
-            log.log('', 2)
-        elif spades_output:
-            log.log(dim(spades_output), 2)
-
-    spades_error = process.stderr.readline().strip().decode()
-    return_code = process.returncode
-    if spades_error:
-        quit_with_error('SPAdes encountered an error: ' + spades_error)
-    if return_code != 0:
-        quit_with_error('SPAdes crashed! Please view spades.log for more information.')
-
-    # Read error correction should be done now, so copy the corrected read files to a more
-    # permanent location.
-    if using_paired_reads:
-        short1_no_extension = strip_read_extensions(short1)
-        short2_no_extension = strip_read_extensions(short2)
-
-        # Try to deal with particularly strange names for paired reads.
-        if short1_no_extension in short2_no_extension or short2_no_extension in short1_no_extension:
-            for i in range(min(len(short1), len(short2))):
-                short1_no_extension = os.path.basename(short1)[:i]
-                short2_no_extension = os.path.basename(short2)[:i]
-                if short1_no_extension != short2_no_extension:
-                    break
-        if short1_no_extension in short2_no_extension or short2_no_extension in short1_no_extension:
-            quit_with_error('could not process read file names')
-    else:
-        short1_no_extension, short2_no_extension = '', ''
-
-    corrected_dir = os.path.join(read_correction_dir, 'corrected')
-    files = os.listdir(corrected_dir)
-    for spades_file in files:
-        file_path = os.path.join(corrected_dir, spades_file)
-        if using_paired_reads and short1_no_extension in spades_file:
-            shutil.move(file_path, corrected_1)
-        elif using_paired_reads and short2_no_extension in spades_file:
-            shutil.move(file_path, corrected_2)
-        elif using_unpaired_reads and '_unpaired' in spades_file:
-            shutil.move(file_path, corrected_u)
-        elif using_unpaired_reads and not using_paired_reads and \
-                spades_file.endswith('.cor.fastq.gz'):
-            shutil.move(file_path, corrected_u)
-
-    corrected_1_exists = os.path.isfile(corrected_1)
-    corrected_2_exists = os.path.isfile(corrected_2)
-    corrected_u_exists = os.path.isfile(corrected_u)
-
-    if using_paired_reads and (not corrected_1_exists or not corrected_2_exists):
-        quit_with_error('SPAdes read error correction failed. '
-                        'See spades_assembly/read_correction/spades.log for more info.')
-    if using_unpaired_reads and not corrected_u_exists:
-        quit_with_error('SPAdes read error correction failed. '
-                        'See spades_assembly/read_correction/spades.log for more info.')
-    if keep < 3:
-        shutil.rmtree(read_correction_dir, ignore_errors=True)
-
-    if not using_paired_reads:
-        corrected_1 = None
-        corrected_2 = None
-    if not using_unpaired_reads:
-        corrected_u = None
-
-    log.log('')
-    log.log('Corrected reads:')
-    if using_paired_reads:
-        log.log('  ' + corrected_1)
-        log.log('  ' + corrected_2)
-    if using_unpaired_reads:
-        log.log('  ' + corrected_u)
-
-    return corrected_1, corrected_2, corrected_u
-
-
-def spades_assembly(read_files, out_dir, kmers, threads, spades_path, spades_tmp_dir,
-                    just_last=False):
-    """
-    This runs a SPAdes assembly, possibly continuing from a previous assembly.
-    """
-    short1 = read_files[0]
-    short2 = read_files[1]
-    unpaired = read_files[2]
-
+    short1, short2, unpaired = read_files[0], read_files[1], read_files[2]
     using_paired_reads = short1 is not None and short2 is not None and \
         os.path.isfile(short1) and os.path.isfile(short2)
     using_unpaired_reads = unpaired is not None and os.path.isfile(unpaired)
 
-    kmer_string = ','.join([str(x) for x in kmers])
-    command = [spades_path, '-o', out_dir, '-k', kmer_string, '--threads', str(threads)]
-    if just_last:
-        command += ['--restart-from', 'k' + str(kmers[-1])]
+    graph_files, insert_size_means, insert_size_deviations = [], [], []
+    for i in range(len(kmers)):
+        biggest_kmer = kmers[i]
+        command = build_spades_command(spades_path, spades_dir, threads, kmers, i, short1, short2,
+                                       unpaired, using_paired_reads, using_unpaired_reads,
+                                       spades_options)
+        log.log(' '.join(command))
+        graph_file, insert_size_mean, insert_size_deviation = \
+            run_spades_one_kmer(command, spades_dir, biggest_kmer)
+
+        copy_path = spades_graph_prefix + '_k' + '{:03d}'.format(biggest_kmer) + '.gfa'
+        shutil.copy(graph_file, copy_path)
+        graph_files.append(copy_path)
+        insert_size_means.append(insert_size_mean)
+        insert_size_deviations.append(insert_size_deviation)
+        log.log('')
+
+    insert_size_means = [x for x in insert_size_means if x is not None]
+    insert_size_deviations = [x for x in insert_size_deviations if x is not None]
+
+    if insert_size_means and insert_size_deviations:
+        insert_size_mean = statistics.median(insert_size_means)
+        insert_size_deviation = statistics.median(insert_size_deviations)
     else:
+        # If we couldn't get the insert size from the SPAdes output (e.g. it was an
+        # unpaired-reads-only assembly), we'll use the read length instead.
+        read_lengths = get_read_lengths(short1) + get_read_lengths(short2) + \
+                       get_read_lengths(unpaired)
+        insert_size_mean = statistics.mean(read_lengths)
+        insert_size_deviation = max(statistics.stdev(read_lengths), 1.0)
+
+    log.log('', 2)
+    log.log('Insert size mean: ' + float_to_str(insert_size_mean, 1) + ' bp', 2)
+    log.log('Insert size stdev: ' + float_to_str(insert_size_deviation, 1) + ' bp', 2)
+    log.log('', 2)
+
+    return graph_files, insert_size_mean, insert_size_deviation
+
+
+def build_spades_command(spades_path, spades_dir, threads, kmers, i, short1, short2, unpaired,
+                         using_paired_reads, using_unpaired_reads, spades_options):
+    kmer_string = ','.join([str(x) for x in kmers[:i+1]])
+
+    command = [spades_path, '-o', spades_dir, '-k', kmer_string, '--threads', str(threads)]
+    if i == 0:  # first k-mer
+        command += ['--isolate']
         if using_paired_reads:
-            command += ['--only-assembler', '-1', short1, '-2', short2]
+            command += ['-1', short1, '-2', short2]
         if using_unpaired_reads:
-            command += ['--only-assembler', '-s', unpaired]
-    if spades_tmp_dir is not None:
-        command += ['--tmp-dir', spades_tmp_dir]
+            command += ['-s', unpaired]
+    else:  # subsequent k-mer
+        previous_k = kmers[i - 1]
+        command += ['--restart-from', f'k{previous_k}']
+    if spades_options:
+        command += spades_options.split()
+    if not spades_options or '-m' not in spades_options.split():
+        command += ['-m', '1024']
+    return command
+
+
+def run_spades_one_kmer(command, spades_dir, biggest_kmer):
     process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
     insert_size_mean = None
@@ -392,39 +267,38 @@ def spades_assembly(read_files, out_dir, kmers, threads, spades_path, spades_tmp
         except ValueError:
             pass
 
-    # If we couldn't get the insert size from the SPAdes output (e.g. it was an unpaired-reads-only
-    # assembly), we'll use the read length instead.
-    if insert_size_mean is None or insert_size_deviation is None:
-        read_lengths = get_read_lengths(short1) + get_read_lengths(short2) + \
-                       get_read_lengths(unpaired)
-        insert_size_mean = statistics.mean(read_lengths)
-        insert_size_deviation = max(statistics.stdev(read_lengths), 1.0)
+    if process.returncode != 0:
+        spades_error = process.stderr.read().strip().decode()
+        quit_with_error('SPAdes encountered an error:\n' + spades_error)
 
-    log.log('', 2)
-    log.log('Insert size mean: ' + float_to_str(insert_size_mean, 1) + ' bp', 2)
-    log.log('Insert size stdev: ' + float_to_str(insert_size_deviation, 1) + ' bp', 2)
-    log.log('', 2)
+    graph_file = os.path.join(spades_dir, 'K' + str(biggest_kmer),
+                              'assembly_graph_with_scaffolds.gfa')
+    if not os.path.isfile(graph_file):
+        quit_with_error('SPAdes failed to produce an assembly graph: ' + str(graph_file))
 
-    spades_error = process.stderr.readline().strip().decode()
-    if spades_error:
-        quit_with_error('SPAdes encountered an error: ' + spades_error)
+    return graph_file, insert_size_mean, insert_size_deviation
 
-    if just_last:
-        graph_file = os.path.join(out_dir, 'K' + str(kmers[-1]), 'assembly_graph.fastg')
-        return graph_file, insert_size_mean, insert_size_deviation
-    else:
-        graph_files = []
-        for kmer in kmers:
-            graph_file = os.path.join(out_dir, 'K' + str(kmer), 'assembly_graph.fastg')
-            if os.path.isfile(graph_file):
-                parent_dir = os.path.dirname(out_dir)
-                copied_graph_file = os.path.join(parent_dir,
-                                                 ('k%03d' % kmer) + '_assembly_graph.fastg')
-                shutil.copyfile(graph_file, copied_graph_file)
-                graph_files.append(copied_graph_file)
-            else:
-                graph_files.append(None)
-        return graph_files, insert_size_mean, insert_size_deviation
+
+def check_fastqs(short1, short2, short_unpaired):
+    using_paired_reads = bool(short1) and bool(short2)
+    using_unpaired_reads = bool(short_unpaired)
+    if using_paired_reads:
+        count_1, count_2 = 0, 0
+        try:
+            count_1 = get_read_count(short1)
+        except BadFastq:
+            quit_with_error('this read file is not a properly formatted FASTQ: ' + short1)
+        try:
+            count_2 = get_read_count(short2)
+        except BadFastq:
+            quit_with_error('this read file is not a properly formatted FASTQ: ' + short2)
+        if count_1 != count_2:
+            quit_with_error('the paired read input files have an unequal number of reads')
+    if using_unpaired_reads:
+        try:
+            get_read_count(short_unpaired)
+        except BadFastq:
+            quit_with_error('this read file is not properly formatted as FASTQ: ' + short_unpaired)
 
 
 def get_max_spades_kmer(spades_path):
@@ -446,11 +320,15 @@ def get_max_spades_kmer(spades_path):
         return 127
 
 
-def get_kmer_range(reads_1_filename, reads_2_filename, unpaired_reads_filename, spades_dir,
-                   kmer_count, min_kmer_frac, max_kmer_frac, spades_path):
+def get_kmer_range(given_kmers, reads_1_filename, reads_2_filename, unpaired_reads_filename,
+                   spades_dir, kmer_count, min_kmer_frac, max_kmer_frac, spades_path):
     """
     Uses the read lengths to determine the k-mer range to be used in the SPAdes assembly.
     """
+    # If the user specified which k-mers to use, we can skip automatic k-mer selection.
+    if given_kmers is not None:
+        return given_kmers
+
     log.log_section_header('Choosing k-mer range for assembly')
     log.log_explanation('Unicycler chooses a k-mer range for SPAdes based on the length of the '
                         'input reads. It uses a wide range of many k-mer sizes to maximise the '
@@ -558,10 +436,10 @@ def get_read_count(reads_filename):
     return read_count
 
 
-def count_segments_in_spades_fastg(fastg_file):
+def count_segments_in_gfa(fastg_file):
     seq_count = 0
     with open(fastg_file, 'rt') as fastg:
         for line in fastg:
-            if line.startswith('>'):
+            if line.startswith('S\t'):
                 seq_count += 1
-    return seq_count // 2
+    return seq_count
